@@ -34,7 +34,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <GL/glew.h>
-#include <GL/glut.h>
+#include "glut_wrap.h"
 #include "readtex.h"
 
 
@@ -584,6 +584,7 @@ drawfire(void)
 	 GLfloat seconds = (t - T0) / 1000.0;
 	 GLfloat fps = Frames / seconds;
 	 sprintf(frbuf, "Frame rate: %f", fps);
+         printf("%s\n", frbuf);
 	 T0 = t;
 	 Frames = 0;
       }
@@ -674,7 +675,7 @@ inittextures(void)
    glBindTexture(GL_TEXTURE_2D, groundid);
 
    glPixelStorei(GL_UNPACK_ALIGNMENT, 4);
-   if (!LoadRGBMipmaps("../images/s128.rgb", GL_RGB)) {
+   if (!LoadRGBMipmaps(DEMOS_DATA_DIR "s128.rgb", GL_RGB)) {
       fprintf(stderr, "Error reading a texture.\n");
       exit(-1);
    }
@@ -696,7 +697,8 @@ inittextures(void)
 	 int w, h;
 	 GLenum format;
 	 int x, y;
-	 GLubyte *image = LoadRGBImage("../images/tree3.rgb", &w, &h, &format);
+	 GLubyte *image = LoadRGBImage(DEMOS_DATA_DIR "tree3.rgb",
+				       &w, &h, &format);
 
 	 if (!image) {
 	    fprintf(stderr, "Error reading a texture.\n");
@@ -722,7 +724,7 @@ inittextures(void)
 	 }
       }
    else {
-      if (!LoadRGBMipmaps("../images/tree2.rgba", GL_RGBA)) {
+      if (!LoadRGBMipmaps(DEMOS_DATA_DIR "tree2.rgba", GL_RGBA)) {
 	 fprintf(stderr, "Error reading a texture.\n");
 	 exit(-1);
       }
